==> dde-calendar_5.8.29.orig.tar.xz: dde-calendar-5.8.29/translations/dde-calendar-service_zh_HK.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_HK">
<context>
    <name>JobRemindManager</name>
    <message>
        <location filename="../calendar-service/src/jobremindmanager.cpp" line="94"/>
        <source>One day before start</source>
        <translation>提前1天提醒</translation>
    </message>
    <message>
        <location filename="../calendar-service/src/jobremindmanager.cpp" line="94"/>
        <location filename="../calendar-service/src/jobremindmanager.cpp" line="98"/>
        <location filename="../calendar-service/src/jobremindmanager.cpp" line="105"/>
        <location filename="../calendar-service/src/jobremindmanager.cpp" line="109"/>
        <source>Close</source>
        <comment>button</comment>
        <translation>關 閉</translation>
    </message>
    <message>
        <location filename="../calendar-service/src/jobremindmanager.cpp" line="98"/>
        <source>Remind me tomorrow</source>
        <translation>明天提醒</translation>
    </message>
    <message>
        <location filename="../calendar-service/src/jobremindmanager.cpp" line="105"/>
        <source>Remind me later</source>
        <translation>稍後提醒</translation>
    </message>
    <message>
        <location filename="../calendar-service/src/jobremindmanager.cpp" line="116"/>
        <source>Schedule Reminder</source>
        <translation>日程提醒</translation>
    </message>
    <message>
        <location filename="../calendar-service/src/jobremindmanager.cpp" line="236"/>
        <location filename="../calendar-service/src/jobremindmanager.cpp" line="245"/>
        <source>%1 to %2</source>
        <translation>%1 至 %2</translation>
    </message>
    <message>
        <location filename="../calendar-service/src/jobremindmanager.cpp" line="317"/>
        <location filename="../calendar-service/src/jobremindmanager.cpp" line="328"/>
        <source>Today</source>
        <translation>今天</translation>
    </message>
    <message>
        <location filename="../calendar-service/src/jobremindmanager.cpp" line="320"/>
        <location filename="../calendar-service/src/jobremindmanager.cpp" line="331"/>
        <source>Tomorrow</source>
        <translation>明天</translation>
    </message>
</context>
</TS>

==> dde-calendar_5.9.5.orig.tar.xz: dde-calendar-5.9.5/translations/dde-calendar-service_zh_HK.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_HK">
<context>
    <name>DAccountDataBase</name>
    <message>
        <source>Work</source>
        <translation>工作</translation>
    </message>
    <message>
        <source>Life</source>
        <translation>生活</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>其他</translation>
    </message>
</context>
<context>
    <name>DAlarmManager</name>
    <message>
        <source>Close</source>
        <comment>button</comment>
        <translation>關 閉</translation>
    </message>
    <message>
        <source>One day before start</source>
        <translation>提前1天提醒</translation>
    </message>
    <message>
        <source>Remind me tomorrow</source>
        <translation>明天提醒</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>稍後提醒</translation>
    </message>
    <message>
        <source>15 mins later</source>
        <translation>15分鐘後</translation>
    </message>
    <message>
        <source>1 hour later</source>
        <translation>1小時後</translation>
    </message>
    <message>
        <source>4 hours later</source>
        <translation>4小時後</translation>
    </message>
    <message>
        <source>Tomorrow</source>
        <translation>明天</translation>
    </message>
    <message>
        <source>Schedule Reminder</source>
        <translation>日程提醒</translation>
    </message>
    <message>
        <source>%1 to %2</source>
        <translation>%1 至 %2</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>今天</translation>
    </message>
</context>
<context>
    <name>JobRemindManager</name>
    <message>
        <source>One day before start</source>
        <translation type="vanished">提前1天提醒</translation>
    </message>
    <message>
        <source>Close</source>
        <comment>button</comment>
        <translation type="vanished">關 閉</translation>
    </message>
    <message>
        <source>Remind me tomorrow</source>
        <translation type="vanished">明天提醒</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation type="vanished">稍後提醒</translation>
    </message>
    <message>
        <source>Schedule Reminder</source>
        <translation type="vanished">日程提醒</translation>
    </message>
    <message>
        <source>%1 to %2</source>
        <translation type="vanished">%1 至 %2</translation>
    </message>
    <message>
        <source>Today</source>
        <translation type="vanished">今天</translation>
    </message>
    <message>
        <source>Tomorrow</source>
        <translation type="vanished">明天</translation>
    </message>
</context>
</TS>
